==> f61d-0.1.11.tar.gz: f61d-0.1.11/f61d/LOGO.py <==
LOGO_CHAR3 = '''
  ______   __   __   _____  
 |  ____| / /  /_ | |  __ \ 
 | |__   / /_   | | | |  | |
 |  __| | '_ \  | | | |  | |
 | |    | (_) | | | | |__| |
 |_|     \___/  |_| |_____/ 
                         
'''
LOGO_CHAR1 = '''

　■■■■■■　　　　■■■　　　　　　■　　　　■■■■　　　
　■　　　　　　　　■　　■■　　　　■■　　　　■　　　■　　
　■　　　　　　　■■　　　■　　　■■■　　　　■　　　■■　
　■　　　　　　　■■　　　　　　　　■■　　　　■　　　　■　
　■　　　　　　　■　■■■　　　　　■■　　　　■　　　　■　
　■■■■■　　　■■　　■■　　　　■■　　　　■　　　　■　
　■　　　　　　　■■　　　■　　　　■■　　　　■　　　　■　
　■　　　　　　　■　　　　■　　　　■■　　　　■　　　　■　
　■　　　　　　　■■　　　■　　　　■■　　　　■　　　■■　
　■　　　　　　　　■　　■■　　　　■■　　　　■　　　■　　
　■　　　　　　　　　■■■　　　　　■■　　　　■■■■　　　

'''
LOGO_CHAR2 = '''

 /$$$$$$$$  /$$$$$$     /$$    /$$$$$$$ 
| $$_____/ /$$__  $$  /$$$$   | $$__  $$
| $$      | $$  \__/ |_  $$   | $$  \ $$
| $$$$$   | $$$$$$$    | $$   | $$  | $$
| $$__/   | $$__  $$   | $$   | $$  | $$
| $$      | $$  \ $$   | $$   | $$  | $$
| $$      |  $$$$$$/  /$$$$$$ | $$$$$$$/
|__/       \______/  |______/ |_______/

'''
LOGO_CHAR4 = '''
 .----------------.  .----------------.  .----------------.  .----------------. 
| .--------------. || .--------------. || .--------------. || .--------------. |
| |  _________   | || |    ______    | || |     __       | || |  ________    | |
| | |_   ___  |  | || |  .' ____ \   | || |    /  |      | || | |_   ___ `.  | |
| |   | |_  \_|  | || |  | |____\_|  | || |    `| |      | || |   | |   `. \ | |
| |   |  _|      | || |  | '____`'.  | || |     | |      | || |   | |    | | | |
| |  _| |_       | || |  | (____) |  | || |    _| |_     | || |  _| |___.' / | |
| | |_____|      | || |  '.______.'  | || |   |_____|    | || | |________.'  | |
| |              | || |              | || |              | || |              | |
| '--------------' || '--------------' || '--------------' || '--------------' |
 '----------------'  '----------------'  '----------------'  '----------------'

 '''
LOGO_CHAR7 = '''
                                                                       
                                                                       
FFFFFFFFFFFFFFFFFFFFFF      66666666      1111111    DDDDDDDDDDDDD        
F::::::::::::::::::::F     6::::::6      1::::::1    D::::::::::::DDD     
F::::::::::::::::::::F    6::::::6      1:::::::1    D:::::::::::::::DD   
FF::::::FFFFFFFFF::::F   6::::::6       111:::::1    DDD:::::DDDDD:::::D  
  F:::::F       FFFFFF  6::::::6           1::::1      D:::::D    D:::::D 
  F:::::F              6::::::6            1::::1      D:::::D     D:::::D
  F::::::FFFFFFFFFF   6::::::6             1::::1      D:::::D     D:::::D
  F:::::::::::::::F  6::::::::66666        1::::l      D:::::D     D:::::D
  F:::::::::::::::F 6::::::::::::::66      1::::l      D:::::D     D:::::D
  F::::::FFFFFFFFFF 6::::::66666:::::6     1::::l      D:::::D     D:::::D
  F:::::F           6:::::6     6:::::6    1::::l      D:::::D     D:::::D
  F:::::F           6:::::6     6:::::6    1::::l      D:::::D    D:::::D 
FF:::::::FF         6::::::66666::::::6 111::::::111 DDD:::::DDDDD:::::D  
F::::::::FF          66:::::::::::::66  1::::::::::1 D:::::::::::::::DD   
F::::::::FF            66:::::::::66    1::::::::::1 D::::::::::::DDD     
FFFFFFFFFFF              666666666      111111111111 DDDDDDDDDDDDD        
                                                                       
'''

LOGO_CHAR8 = '''
         _           _      _                   _         
        /\ \       /\ \    / /\                /\ \       
       /  \ \     /  \ \  / /  \              /  \ \____  
      / /\ \ \   / /\ \_\/_/ /\ \            / /\ \_____\ 
     / / /\ \_\ / / /\/_/\_\/\ \ \          / / /\/___  / 
    / /_/_ \/_// /_/_         \ \ \        / / /   / / /  
   / /____/\  / /___/\         \ \ \      / / /   / / /   
  / /\____\/ / /\__ \ \         \ \ \    / / /   / / /    
 / / /      / / /__\ \ \       __\ \ \___\ \ \__/ / /     
/ / /      / / /____\ \ \     /___\_\/__/\\ \___\/ /      
\/_/       \/__________\/     \_________\/ \/_____/       
                                                          

'''


lc9 = '''
__/\\\\\\\\\\\\\\\_____________/\\\\\_______/\\\___/\\\\\\\\\\\\____        
 _\/\\\///////////__________/\\\\////____/\\\\\\\__\/\\\////////\\\__       
  _\/\\\__________________/\\\///________\/////\\\__\/\\\______\//\\\_      
   _\/\\\\\\\\\\\________/\\\\\\\\\\\_________\/\\\__\/\\\_______\/\\\_     
    _\/\\\///////________/\\\\///////\\\_______\/\\\__\/\\\_______\/\\\_    
     _\/\\\______________\/\\\______\//\\\______\/\\\__\/\\\_______\/\\\_   
      _\/\\\______________\//\\\______/\\\_______\/\\\__\/\\\_______/\\\__  
       _\/\\\_______________\///\\\\\\\\\/________\/\\\__\/\\\\\\\\\\\\/___ 
        _\///__________________\/////////__________\///_ _\////////////_____

'''
lc10 = '''


███████╗  ██████╗  ██╗ ██████╗ 
██╔════╝ ██╔════╝ ███║ ██╔══██╗
█████╗   ███████╗╚ ██║ ██║  ██║
██╔══╝   ██╔═══██╗ ██║ ██║  ██║
██║      ╚██████╔╝ ██║ ██████╔╝
╚═╝       ╚═════╝  ╚═╝ ╚═════╝ 
                            

'''
lc11 = '''

 ▄▄▄▄▄▄▄▄▄▄▄  ▄▄▄▄▄▄▄▄▄▄▄     ▄▄▄▄      ▄▄▄▄▄▄▄▄▄▄  
▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌  ▄█░░░░▌    ▐░░░░░░░░░░▌ 
▐░█▀▀▀▀▀▀▀▀▀ ▐░█▀▀▀▀▀▀▀▀▀  ▐░░▌▐░░▌    ▐░█▀▀▀▀▀▀▀█░▌
▐░▌          ▐░▌            ▀▀ ▐░░▌    ▐░▌       ▐░▌
▐░█▄▄▄▄▄▄▄▄▄ ▐░█▄▄▄▄▄▄▄▄▄      ▐░░▌    ▐░▌       ▐░▌
▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌     ▐░░▌    ▐░▌       ▐░▌
▐░█▀▀▀▀▀▀▀▀▀ ▐░█▀▀▀▀▀▀▀█░▌     ▐░░▌    ▐░▌       ▐░▌
▐░▌          ▐░▌       ▐░▌     ▐░░▌    ▐░▌       ▐░▌
▐░▌          ▐░█▄▄▄▄▄▄▄█░▌ ▄▄▄▄█░░█▄▄▄ ▐░█▄▄▄▄▄▄▄█░▌
▐░▌          ▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌▐░░░░░░░░░░▌ 
 ▀            ▀▀▀▀▀▀▀▀▀▀▀  ▀▀▀▀▀▀▀▀▀▀▀  ▀▀▀▀▀▀▀▀▀▀  
                                                    

'''
lc12 = '''
                                     
 _|_|_|_|    _|_|_|    _|  _|_|_|    
 _|        _|        _|_|  _|    _|  
 _|_|_|    _|_|_|      _|  _|    _|  
 _|        _|    _|    _|  _|    _|  
 _|          _|_|      _|  _|_|_|    
                                     
'''

lc13 = '''
8888888888  .d8888b.    d888    8888888b.  
888        d88P  Y88b  d8888    888  "Y88b 
888        888           888    888    888 
8888888    888d888b.     888    888    888 
888        888P "Y88b    888    888    888 
888        888    888    888    888    888 
888        Y88b  d88P    888    888  .d88P 
888         "Y8888P"   8888888  8888888P"  
                                         
                                         
'''
lc14 = '''
=========================================
=        ===       ======  =====       ==
=  ========  =====  ====   =====  ====  =
=  ========  ============  =====  ====  =
=  ========       =======  =====  ====  =
=      ====   ===  ======  =====  ====  =
=  ========  =====  =====  =====  ====  =
=  ========  =====  =====  =====  ====  =
=  =========  ===   =====  =====  ====  =
=  ==========     =====      ===       ==
=========================================

'''


#
logos = [LOGO_CHAR1,LOGO_CHAR2,LOGO_CHAR3,LOGO_CHAR4,LOGO_CHAR7,
         LOGO_CHAR8,lc9,lc10,lc11,lc12,lc13,lc14]
from random import choice

def randlogo():
    return choice(logos)

==> f61d-0.3.10.tar.gz: f61d-0.3.10/f61d/LOGO.py <==
LOGO_CHAR3 = '''
  ______   __   __   _____  
 |  ____| / /  /_ | |  __ \ 
 | |__   / /_   | | | |  | |
 |  __| | '_ \  | | | |  | |
 | |    | (_) | | | | |__| |
 |_|     \___/  |_| |_____/ '''


LOGO_CHAR1 = '''

　■■■■■■　　　　■■■　　　　　　■　　　　■■■■　　　
　■　　　　　　　　■　　■■　　　　■■　　　　■　　　■　　
　■　　　　　　　■■　　　■　　　■■■　　　　■　　　■■　
　■　　　　　　　■■　　　　　　　　■■　　　　■　　　　■　
　■　　　　　　　■　■■■　　　　　■■　　　　■　　　　■　
　■■■■■　　　■■　　■■　　　　■■　　　　■　　　　■　
　■　　　　　　　■■　　　■　　　　■■　　　　■　　　　■　
　■　　　　　　　■　　　　■　　　　■■　　　　■　　　　■　
　■　　　　　　　■■　　　■　　　　■■　　　　■　　　■■　
　■　　　　　　　　■　　■■　　　　■■　　　　■　　　■　　
　■　　　　　　　　　■■■　　　　　■■　　　　■■■■　　 '''


LOGO_CHAR2 = '''

 /$$$$$$$$  /$$$$$$     /$$    /$$$$$$$ 
| $$_____/ /$$__  $$  /$$$$   | $$__  $$
| $$      | $$  \__/ |_  $$   | $$  \ $$
| $$$$$   | $$$$$$$    | $$   | $$  | $$
| $$__/   | $$__  $$   | $$   | $$  | $$
| $$      | $$  \ $$   | $$   | $$  | $$
| $$      |  $$$$$$/  /$$$$$$ | $$$$$$$/
|__/       \______/  |______/ |_______/  '''


LOGO_CHAR4 = '''
 .----------------.  .----------------.  .----------------.  .----------------. 
| .--------------. || .--------------. || .--------------. || .--------------. |
| |  _________   | || |    ______    | || |     __       | || |  ________    | |
| | |_   ___  |  | || |  .' ____ \   | || |    /  |      | || | |_   ___ `.  | |
| |   | |_  \_|  | || |  | |____\_|  | || |    `| |      | || |   | |   `. \ | |
| |   |  _|      | || |  | '____`'.  | || |     | |      | || |   | |    | | | |
| |  _| |_       | || |  | (____) |  | || |    _| |_     | || |  _| |___.' / | |
| | |_____|      | || |  '.______.'  | || |   |_____|    | || | |________.'  | |
| |              | || |              | || |              | || |              | |
| '--------------' || '--------------' || '--------------' || '--------------' |
 '----------------'  '----------------'  '----------------'  '----------------' '''


LOGO_CHAR7 = '''
                                                                                                                 
FFFFFFFFFFFFFFFFFFFFFF      66666666      1111111    DDDDDDDDDDDDD        
F::::::::::::::::::::F     6::::::6      1::::::1    D::::::::::::DDD     
F::::::::::::::::::::F    6::::::6      1:::::::1    D:::::::::::::::DD   
FF::::::FFFFFFFFF::::F   6::::::6       111:::::1    DDD:::::DDDDD:::::D  
  F:::::F       FFFFFF  6::::::6           1::::1      D:::::D    D:::::D 
  F:::::F              6::::::6            1::::1      D:::::D     D:::::D
  F::::::FFFFFFFFFF   6::::::6             1::::1      D:::::D     D:::::D
  F:::::::::::::::F  6::::::::66666        1::::l      D:::::D     D:::::D
  F:::::::::::::::F 6::::::::::::::66      1::::l      D:::::D     D:::::D
  F::::::FFFFFFFFFF 6::::::66666:::::6     1::::l      D:::::D     D:::::D
  F:::::F           6:::::6     6:::::6    1::::l      D:::::D     D:::::D
  F:::::F           6:::::6     6:::::6    1::::l      D:::::D    D:::::D 
FF:::::::FF         6::::::66666::::::6 111::::::111 DDD:::::DDDDD:::::D  
F::::::::FF          66:::::::::::::66  1::::::::::1 D:::::::::::::::DD   
F::::::::FF            66:::::::::66    1::::::::::1 D::::::::::::DDD     
FFFFFFFFFFF              666666666      111111111111 DDDDDDDDDDDDD         '''


LOGO_CHAR8 = '''
         _           _      _                   _         
        /\ \       /\ \    / /\                /\ \       
       /  \ \     /  \ \  / /  \              /  \ \____  
      / /\ \ \   / /\ \_\/_/ /\ \            / /\ \_____\ 
     / / /\ \_\ / / /\/_/\_\/\ \ \          / / /\/___  / 
    / /_/_ \/_// /_/_         \ \ \        / / /   / / /  
   / /____/\  / /___/\         \ \ \      / / /   / / /   
  / /\____\/ / /\__ \ \         \ \ \    / / /   / / /    
 / / /      / / /__\ \ \       __\ \ \___\ \ \__/ / /     
/ / /      / / /____\ \ \     /___\_\/__/\\ \___\/ /      
\/_/       \/__________\/     \_________\/ \/_____/       '''




lc9 = '''
__/\\\\\\\\\\\\\\\_____________/\\\\\_______/\\\____/\\\\\\\\\\\\____        
 _\/\\\///////////__________/\\\\////____/\\\\\\\___\/\\\////////\\\__       
  _\/\\\__________________/\\\///________\/////\\\___\/\\\______\//\\\_      
   _\/\\\\\\\\\\\________/\\\\\\\\\\\_________\/\\\___\/\\\_______\/\\\_     
    _\/\\\///////________/\\\\///////\\\_______\/\\\___\/\\\_______\/\\\_    
     _\/\\\______________\/\\\______\//\\\______\/\\\___\/\\\_______\/\\\_   
      _\/\\\______________\//\\\______/\\\_______\/\\\___\/\\\_______/\\\__  
       _\/\\\_______________\///\\\\\\\\\/________\/\\\___\/\\\\\\\\\\\\/___ 
        _\///__________________\/////////__________\///____\////////////_____ '''



lc10 = '''


███████╗  ██████╗  ██╗ ██████╗ 
██╔════╝ ██╔════╝ ███║ ██╔══██╗
█████╗   ███████╗╚ ██║ ██║  ██║
██╔══╝   ██╔═══██╗ ██║ ██║  ██║
██║      ╚██████╔╝ ██║ ██████╔╝
╚═╝       ╚═════╝  ╚═╝ ╚═════╝    '''


lc11 = '''

 ▄▄▄▄▄▄▄▄▄▄▄  ▄▄▄▄▄▄▄▄▄▄▄     ▄▄▄▄      ▄▄▄▄▄▄▄▄▄▄  
▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌  ▄█░░░░▌    ▐░░░░░░░░░░▌ 
▐░█▀▀▀▀▀▀▀▀▀ ▐░█▀▀▀▀▀▀▀▀▀  ▐░░▌▐░░▌    ▐░█▀▀▀▀▀▀▀█░▌
▐░▌          ▐░▌            ▀▀ ▐░░▌    ▐░▌       ▐░▌
▐░█▄▄▄▄▄▄▄▄▄ ▐░█▄▄▄▄▄▄▄▄▄      ▐░░▌    ▐░▌       ▐░▌
▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌     ▐░░▌    ▐░▌       ▐░▌
▐░█▀▀▀▀▀▀▀▀▀ ▐░█▀▀▀▀▀▀▀█░▌     ▐░░▌    ▐░▌       ▐░▌
▐░▌          ▐░▌       ▐░▌     ▐░░▌    ▐░▌       ▐░▌
▐░▌          ▐░█▄▄▄▄▄▄▄█░▌ ▄▄▄▄█░░█▄▄▄ ▐░█▄▄▄▄▄▄▄█░▌
▐░▌          ▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌▐░░░░░░░░░░▌ 
 ▀            ▀▀▀▀▀▀▀▀▀▀▀  ▀▀▀▀▀▀▀▀▀▀▀  ▀▀▀▀▀▀▀▀▀▀     '''


lc12 = '''
                                     
 _|_|_|_|    _|_|_|    _|  _|_|_|    
 _|        _|        _|_|  _|    _|  
 _|_|_|    _|_|_|      _|  _|    _|  
 _|        _|    _|    _|  _|    _|  
 _|          _|_|      _|  _|_|_|    '''



lc13 = '''
8888888888  .d8888b.    d888    8888888b.  
888        d88P  Y88b  d8888    888  "Y88b 
888        888           888    888    888 
8888888    888d888b.     888    888    888 
888        888P "Y88b    888    888    888 
888        888    888    888    888    888 
888        Y88b  d88P    888    888  .d88P 
888         "Y8888P"   8888888  8888888P"   '''



lc14 = '''
=========================================
=        ===       ======  =====       ==
=  ========  =====  ====   =====  ====  =
=  ========  ============  =====  ====  =
=  ========       =======  =====  ====  =
=      ====   ===  ======  =====  ====  =
=  ========  =====  =====  =====  ====  =
=  ========  =====  =====  =====  ====  =
=  =========  ===   =====  =====  ====  =
=  ==========     =====      ===       ==
=========================================  '''




logos = [LOGO_CHAR1,LOGO_CHAR2,LOGO_CHAR3,LOGO_CHAR4,LOGO_CHAR7,
         LOGO_CHAR8,lc9,lc10,lc11,lc12,lc13,lc14]
from random import choice

def randlogo():
    return choice(logos)
